<?php
/*************************************************************
 * 1) Load Config
 *************************************************************/
$configFile = 'config.json';
if (file_exists($configFile)) {
    $config = json_decode(file_get_contents($configFile), true);
} else {
    exit("Error: Configuration file not found.");
}

// Cloud selection
$cloudProvider = isset($config['cloudProvider']) ? strtolower($config['cloudProvider']) : 'azure';

// Azure
$azureConnectionString = $config['azureConnectionString'] ?? "";
$azureContainerName    = $config['azureContainerName']    ?? "";

// AWS
$awsAccessKey   = $config['awsAccessKey']   ?? "";
$awsSecretKey   = $config['awsSecretKey']   ?? "";
$awsRegion      = $config['awsRegion']      ?? "us-east-1";
$awsBucketName  = $config['awsBucketName']  ?? "";

/*************************************************************
 * 2) Include Libraries
 *************************************************************/
require 'vendor/autoload.php'; // Azure Blob SDK + AWS SDK

use MicrosoftAzure\Storage\Blob\BlobRestProxy;
use MicrosoftAzure\Storage\Blob\Models\ListBlobsOptions;
use Aws\S3\S3Client;
use Aws\S3\Exception\S3Exception;

/*************************************************************
 * 3) Helper Functions
 *************************************************************/
function createBlobClient($connectionString) {
    return BlobRestProxy::createBlobService($connectionString);
}

function createS3Client($awsAccessKey, $awsSecretKey, $awsRegion) {
    return new S3Client([
        'version'     => 'latest',
        'region'      => $awsRegion,
        'credentials' => [
            'key'    => $awsAccessKey,
            'secret' => $awsSecretKey,
        ],
    ]);
}

/*************************************************************
 * 4) Handle "Clear All" if clicked
 *************************************************************/
$deleteMessage = "";
$deleteError   = "";

if (isset($_POST['clear_blobs'])) {

    if ($cloudProvider === 'aws') {
        /****************************
         * Clear from AWS S3 Bucket
         ****************************/
        try {
            $s3Client = createS3Client($awsAccessKey, $awsSecretKey, $awsRegion);

            // List all objects in the bucket
            $objects = $s3Client->listObjectsV2([
                'Bucket' => $awsBucketName
            ]);

            if (isset($objects['Contents'])) {
                // Prepare keys to delete
                $keysToDelete = [];
                foreach ($objects['Contents'] as $object) {
                    $keysToDelete[] = ['Key' => $object['Key']];
                }

                if (!empty($keysToDelete)) {
                    $result = $s3Client->deleteObjects([
                        'Bucket'  => $awsBucketName,
                        'Delete'  => [
                            'Objects' => $keysToDelete
                        ],
                    ]);
                    $deleteMessage = "All objects in AWS bucket '{$awsBucketName}' have been successfully deleted.";
                } else {
                    $deleteMessage = "No objects found in AWS bucket '{$awsBucketName}'.";
                }
            } else {
                $deleteMessage = "No objects found in AWS bucket '{$awsBucketName}'.";
            }
        } catch (S3Exception $e) {
            $deleteError = "Error deleting S3 objects: " . $e->getMessage();
        }

    } else {
        /****************************
         * Clear from Azure Container
         ****************************/
        try {
            $blobClient = createBlobClient($azureConnectionString);
            $listBlobsOptions = new ListBlobsOptions();
            $blobList = $blobClient->listBlobs($azureContainerName, $listBlobsOptions);
            $blobs = $blobList->getBlobs();

            foreach ($blobs as $blob) {
                $blobClient->deleteBlob($azureContainerName, $blob->getName());
            }

            $deleteMessage = "All blobs in Azure container '{$azureContainerName}' have been successfully deleted.";
        } catch (Exception $e) {
            $deleteError = "Error deleting Azure blobs: " . $e->getMessage();
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Binary Rain Effect</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- (Optional) Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            margin: 0;
            overflow: hidden;
            background: #000;
            font-family: Arial, sans-serif;
        }
        canvas {
            position: absolute;
            top: 0;
            left: 0;
            width: 100vw;
            height: 100vh;
        }
        .container {
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            text-align: center;
            z-index: 1;
        }
        h1 {
            color: #00ff00;
            margin-bottom: 30px;
        }
        .btn-custom {
            border: 1px solid #00ff00;
            background: transparent;
            color: #00ff00;
            font-size: 18px;
            padding: 10px 20px;
            margin: 10px;
            border-radius: 5px;
            transition: 0.3s;
            text-decoration: none;
            display: inline-block;
        }
        .btn-custom:hover {
            background: #00ff00;
            color: #000;
        }
        .alert {
            margin-top: 20px;
            padding: 15px;
            border-radius: 5px;
            color: #fff;
            background-color: #333;
            display: inline-block;
        }
        .alert.success {
            border: 1px solid #00ff00;
        }
        .alert.error {
            border: 1px solid #ff0000;
        }
    </style>
</head>
<body>
<canvas id="binaryCanvas"></canvas>
<div class="container text-center">
    <h1>Choose Your Page</h1>
    <!-- Existing Buttons -->
    <a href="page1.php" class="btn-custom">Manage your Settings</a>
    <a href="page2.php" class="btn-custom">UUID Extractor &amp; URL Generator</a>

    <!-- "Clear All" Button -->
    <form method="post" style="margin-top: 20px;">
        <button 
            type="submit" 
            name="clear_blobs" 
            class="btn-custom"
            onclick="return confirm('Are you sure you want to delete all uploaded items? This cannot be undone.')"
        >
            Clear All Files (<?php echo ucfirst($cloudProvider); ?>)
        </button>
    </form>

    <!-- Display Success/Error messages -->
    <?php if(!empty($deleteMessage)): ?>
        <div class="alert success"><?php echo $deleteMessage; ?></div>
    <?php elseif(!empty($deleteError)): ?>
        <div class="alert error"><?php echo $deleteError; ?></div>
    <?php endif; ?>
</div>

<script>
    const canvas = document.getElementById("binaryCanvas");
    const ctx = canvas.getContext("2d");
    canvas.width = window.innerWidth;
    canvas.height = window.innerHeight;

    const binaryChars = "010101010110110001010".split("");
    const fontSize = 16;
    const columns = Math.floor(canvas.width / fontSize);
    const drops = Array(columns).fill(0);
    let mouseX = -1, mouseY = -1;

    function draw() {
        ctx.fillStyle = "rgba(0, 0, 0, 0.05)";
        ctx.fillRect(0, 0, canvas.width, canvas.height);
        ctx.font = fontSize + "px monospace";

        for (let i = 0; i < drops.length; i++) {
            const text = binaryChars[Math.floor(Math.random() * binaryChars.length)];
            const x = i * fontSize;
            const y = drops[i] * fontSize;

            const dx = mouseX - x;
            const dy = mouseY - y;
            const distance = Math.sqrt(dx * dx + dy * dy);
            const brightness = Math.max(0, 255 - distance * 0.5);
            ctx.fillStyle = `rgb(0, ${brightness}, 0)`;

            ctx.fillText(text, x, y);

            if (y > canvas.height && Math.random() > 0.975) {
                drops[i] = 0;
            }
            drops[i]++;
        }
    }

    function animate() {
        draw();
        requestAnimationFrame(animate);
    }

    window.addEventListener("resize", () => {
        canvas.width = window.innerWidth;
        canvas.height = window.innerHeight;
    });

    document.addEventListener("mousemove", (e) => {
        mouseX = e.clientX;
        mouseY = e.clientY;
    });

    animate();
</script>
</body>
</html>
